@@ -1,12 +1,14 @@
 import CoreServices
-from PyObjCTools.TestSupport import TestCase, os_release, onlyIf
+from PyObjCTools.TestSupport import TestCase, os_release, skipUnless
 
 
 class TestDictionaryServices(TestCase):
     def testClasses(self):
         self.assertIsCFType(CoreServices.DCSDictionaryRef)
 
-    @onlyIf(os_release().rsplit(".", 1)[0] not in ("10.12", "10.13"))
+    @skipUnless(
+        os_release().rsplit(".", 1)[0] not in ("10.12", "10.13"), "buggy os release"
+    )
     def testFunctions(self):
         txt = "the hello world program"
         r = CoreServices.DCSGetTermRangeInString(None, txt, 5)
